@@ -1,6 +1,6 @@
 /************************************************************
  *
- * COPYRIGHT (C) HITACHI,LTD. 2003 ALL RIGHTS RESERVED.
+ * COPYRIGHT (C) HITACHI,LTD. 2003-2004
  * WRITTEN BY HITACHI SYSTEMS DEVELOPMENT LABORATORY,
  *            HITACHI CENTRAL RESEARCH LABORATORY.
  *
@@ -10,6 +10,8 @@
 
 #include "ktask.h"
 
+#define __KERNEL__
+#include <linux/compiler.h>
 #include <linux/sched.h>
 
 
